==> zio-aws-rds_3-5.17.129.1-sources.jar: zio/aws/rds/model/AuthorizeDbSecurityGroupIngressResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class AuthorizeDbSecurityGroupIngressResponse(
    dbSecurityGroup: scala.Option[zio.aws.rds.model.DBSecurityGroup] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.AuthorizeDbSecurityGroupIngressResponse = {
    import AuthorizeDbSecurityGroupIngressResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.AuthorizeDbSecurityGroupIngressResponse
      .builder()
      .optionallyWith(dbSecurityGroup.map(value => value.buildAwsValue()))(
        _.dbSecurityGroup
      )
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.AuthorizeDbSecurityGroupIngressResponse.ReadOnly =
    zio.aws.rds.model.AuthorizeDbSecurityGroupIngressResponse
      .wrap(buildAwsValue())
}
object AuthorizeDbSecurityGroupIngressResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.AuthorizeDbSecurityGroupIngressResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.AuthorizeDbSecurityGroupIngressResponse =
      zio.aws.rds.model.AuthorizeDbSecurityGroupIngressResponse(
        dbSecurityGroup.map(value => value.asEditable)
      )
    def dbSecurityGroup
        : scala.Option[zio.aws.rds.model.DBSecurityGroup.ReadOnly]
    def getDbSecurityGroup
        : ZIO[Any, AwsError, zio.aws.rds.model.DBSecurityGroup.ReadOnly] =
      AwsError.unwrapOptionField("dbSecurityGroup", dbSecurityGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.AuthorizeDbSecurityGroupIngressResponse
  ) extends zio.aws.rds.model.AuthorizeDbSecurityGroupIngressResponse.ReadOnly {
    override val dbSecurityGroup
        : scala.Option[zio.aws.rds.model.DBSecurityGroup.ReadOnly] = scala
      .Option(impl.dbSecurityGroup())
      .map(value => zio.aws.rds.model.DBSecurityGroup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.AuthorizeDbSecurityGroupIngressResponse
  ): zio.aws.rds.model.AuthorizeDbSecurityGroupIngressResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-rds_3-5.17.203.2-sources.jar: zio/aws/rds/model/AuthorizeDbSecurityGroupIngressResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class AuthorizeDbSecurityGroupIngressResponse(
    dbSecurityGroup: Optional[zio.aws.rds.model.DBSecurityGroup] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.AuthorizeDbSecurityGroupIngressResponse = {
    import AuthorizeDbSecurityGroupIngressResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.AuthorizeDbSecurityGroupIngressResponse
      .builder()
      .optionallyWith(dbSecurityGroup.map(value => value.buildAwsValue()))(
        _.dbSecurityGroup
      )
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.AuthorizeDbSecurityGroupIngressResponse.ReadOnly =
    zio.aws.rds.model.AuthorizeDbSecurityGroupIngressResponse
      .wrap(buildAwsValue())
}
object AuthorizeDbSecurityGroupIngressResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.AuthorizeDbSecurityGroupIngressResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.AuthorizeDbSecurityGroupIngressResponse =
      zio.aws.rds.model.AuthorizeDbSecurityGroupIngressResponse(
        dbSecurityGroup.map(value => value.asEditable)
      )
    def dbSecurityGroup: Optional[zio.aws.rds.model.DBSecurityGroup.ReadOnly]
    def getDbSecurityGroup
        : ZIO[Any, AwsError, zio.aws.rds.model.DBSecurityGroup.ReadOnly] =
      AwsError.unwrapOptionField("dbSecurityGroup", dbSecurityGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.AuthorizeDbSecurityGroupIngressResponse
  ) extends zio.aws.rds.model.AuthorizeDbSecurityGroupIngressResponse.ReadOnly {
    override val dbSecurityGroup
        : Optional[zio.aws.rds.model.DBSecurityGroup.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbSecurityGroup())
        .map(value => zio.aws.rds.model.DBSecurityGroup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.AuthorizeDbSecurityGroupIngressResponse
  ): zio.aws.rds.model.AuthorizeDbSecurityGroupIngressResponse.ReadOnly =
    new Wrapper(impl)
}
